@@ -305,28 +305,19 @@ def projects(ctx, i):
   try:
     projects = ctx.obj.projects()
     proj_names = {}
-    proj_cats = {"reg": {}, "pilot": {}}
+    all_proj = {}
     for proj in projects:
-      proj_names[proj.attributes['name']] =  proj.id
-      if proj.attributes["is_developer"]:
-        proj_cats["pilot"][proj.attributes['name']] =  proj.id
-      else:
-        proj_cats["reg"][proj.attributes['name']] =  proj.id
+      status = " (archived)" if proj.attributes['archived_at'] else ""
+      proj_names[proj.attributes['name']] = proj.id
+      all_proj[proj.attributes['name'] + status] = proj.id
     if i:
-      return {k.lower(): v for k,v in list(proj_names.items())}
+      return proj_names
     else:
-      for cat, packages in list(proj_cats.items()):
-        if cat == "reg":
-          click.echo('\n{:^80}'.format("PROJECTS:\n"))
-          click.echo('{:^40}'.format("PROJECT NAME") + "|" +
-                     '{:^40}'.format("PROJECT ID"))
-          click.echo('{:-^80}'.format(''))
-        elif cat == "pilot" and list(packages.values()):
-          click.echo('\n{:^80}'.format("PILOT PROJECTS:\n"))
-          click.echo('{:^40}'.format("PROJECT NAME") + "|" +
-                     '{:^40}'.format("PROJECT ID"))
-          click.echo('{:-^80}'.format(''))
-        for name, i in list(packages.items()):
+      click.echo('\n{:^80}'.format("PROJECTS:\n"))
+      click.echo('{:^40}'.format("PROJECT NAME") + "|" +
+                 '{:^40}'.format("PROJECT ID"))
+      click.echo('{:-^80}'.format(''))
+      for name, i in list(all_proj.items()):
           click.echo('{:<40}'.format(name) + "|" +
                      '{:^40}'.format(i))
           click.echo('{:-^80}'.format(''))
@@ -334,6 +325,38 @@ def projects(ctx, i):
     click.echo("There was an error listing the projects in your "
                "organization.  Make sure your login details are correct.")
 
+@cli.command()
+@click.pass_context
+@click.argument('project_name')
+def runs(ctx, project_name):
+  '''List the runs that exist in a project'''
+  id = get_project_id(project_name)
+  runs = []
+  if id:
+    req = ctx.obj.runs(id)
+    if not req['runs']:
+      click.echo("Project '%s' is empty." % project_name)
+      return
+    for r in req['runs']:
+      runs.append([r['title'] or "(Untitled)",
+                  r['id'],
+                  r['completed_at'].split("T")[0] if r['completed_at'] else r['created_at'].split("T")[0],
+                  r['status'].replace("_", " ")])
+
+    click.echo('\n{:^120}'.format("Runs in Project '%s':\n" % get_project_name(project_name)))
+    click.echo('{:^30}'.format("RUN TITLE") + "|" +
+               '{:^30}'.format("RUN ID") + "|" +
+               '{:^30}'.format("RUN DATE") + "|" +
+               '{:^30}'.format('RUN STATUS'))
+    click.echo('{:-^120}'.format(''))
+    for run in runs:
+        click.echo('{:^30}'.format(run[0]) + "|" +
+                   '{:^30}'.format(run[1]) + "|" +
+                   '{:^30}'.format(run[2]) + "|" +
+                   '{:^30}'.format(run[3]))
+        click.echo('{:-^120}'.format(''))
+
+
 @cli.command("create-project")
 @click.argument('name', metavar = "PROJECT_NAME")
 @click.option('--dev', '-d', '-pilot', help = "Create a pilot project", is_flag = True)
@@ -347,7 +370,7 @@ def create_project(ctx, name, dev):
                  "  Please choose a different project name." % name)
       return
   try:
-    new_proj = ctx.obj.create_project(name, is_developer = dev)
+    new_proj = ctx.obj.create_project(name)
     click.echo(
       "New%s project '%s' created with id %s  \nView it at %s" % (
         " pilot" if dev else "", name, new_proj.attributes['id'], ctx.obj.url('%s' % (new_proj.attributes['id']))
@@ -618,11 +641,11 @@ def login(ctx, api_root):
 @click.pass_context
 def get_project_id(ctx, name):
   projs = ctx.invoke(projects, i=True)
-  id = projs.get(name.lower())
+  id = projs.get(name)
   if not id:
     id = name if name in list(projs.values()) else None
     if not id:
-      click.echo("A project with the name '%s' was not found in your organization." % name)
+      click.echo("The project '%s' was not found in your organization." % name)
       return
   return id
 
@@ -633,7 +656,7 @@ def get_project_name(ctx, id):
   if not name:
     name = id if name in list(projs.keys()) else None
     if not name:
-      click.echo("A project with the id '%s' was not found in your organization." % name)
+      click.echo("The project '%s' was not found in your organization." % name)
       return
   return name
 
